aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorElliott Hughes <enh@google.com>2013-06-26 09:47:52 -0700
committerElliott Hughes <enh@google.com>2013-06-26 14:11:18 -0700
commita8f744cec5125866672e131f328cc5a6e35c9173 (patch)
treeae5557564e744d1159fec7c2bd67bfb153c0aa25
parentcabef9ca2411d98a54885f94adfff25eef921c19 (diff)
downloadicu4c-jb-mr2.0.0-release.tar.gz
(cherry picked from commit c54e7799689c9180053771dfce37f2e25054febd) Change-Id: I309b35a577e0634cc7adeb3bf458bbe9559dcd7a
-rw-r--r--data/curr/tr.txt2
-rw-r--r--stubdata/icudt50l-all.datbin17707216 -> 17802224 bytes
-rw-r--r--stubdata/icudt50l-default.datbin11551120 -> 11608560 bytes
-rwxr-xr-xstubdata/regenerate.sh27
4 files changed, 17 insertions, 12 deletions
diff --git a/data/curr/tr.txt b/data/curr/tr.txt
index eda15c7c..f5881d37 100644
--- a/data/curr/tr.txt
+++ b/data/curr/tr.txt
@@ -900,7 +900,7 @@ tr{
"Eski Türk Lirası",
}
TRY{
- "₺",
+ "TL",
"Türk Lirası",
}
TTD{
diff --git a/stubdata/icudt50l-all.dat b/stubdata/icudt50l-all.dat
index 5bad8e5f..b3839fd9 100644
--- a/stubdata/icudt50l-all.dat
+++ b/stubdata/icudt50l-all.dat
Binary files differ
diff --git a/stubdata/icudt50l-default.dat b/stubdata/icudt50l-default.dat
index 380208dc..96d624a1 100644
--- a/stubdata/icudt50l-default.dat
+++ b/stubdata/icudt50l-default.dat
Binary files differ
diff --git a/stubdata/regenerate.sh b/stubdata/regenerate.sh
index 32c8be51..d1e52d6b 100755
--- a/stubdata/regenerate.sh
+++ b/stubdata/regenerate.sh
@@ -28,22 +28,27 @@ ICU4C_DIR=$ANDROID_BUILD_TOP/external/icu4c
# Make a temporary directory.
rm -rf $ICU4C_DIR/tmp
mkdir $ICU4C_DIR/tmp
-mkdir $ICU4C_DIR/tmp/region
-
-# Compile the region .txt files to .res files.
-# TODO: expand this to more than just the region files.
-cd $ICU4C_DIR/data/region
-for locale in *.txt ;
-do
- $ICU_BIN/genrb -d $ICU4C_DIR/tmp/region ../../data/region/$locale
+
+# TODO: expand this to more than just the curr and region files.
+data_kinds="curr region"
+
+for data_kind in $data_kinds ; do
+ mkdir $ICU4C_DIR/tmp/$data_kind
+
+ # Compile the .txt files to .res files.
+ cd $ICU4C_DIR/data/$data_kind
+ for locale in *.txt ; do
+ $ICU_BIN/genrb -d $ICU4C_DIR/tmp/$data_kind ../../data/$data_kind/$locale
+ done
done
# Create a copy of the .dat file that uses the new .res files.
cp $ICU4C_DIR/stubdata/icudt${ICU_VERSION}l-all.dat $ICU4C_DIR/tmp/icudt${ICU_VERSION}l.dat
cd $ICU4C_DIR/tmp
-for res in region/*.res ;
-do
- $ICU_BIN/icupkg -a $res icudt${ICU_VERSION}l.dat
+for data_kind in $data_kinds ; do
+ for res in $data_kind/*.res ; do
+ $ICU_BIN/icupkg -a $res icudt${ICU_VERSION}l.dat
+ done
done
# Make the modified .dat file the canonical copy.